#ifndef _AUTOTHROTTLE_H_
#define _AUTOTHROTTLE_H_

/* Struct of throttling states. */
typedef struct scale {
	int up;
	int down;
} scale;

/* Performs a test of the user-specified CPU and ACPI-states.
 * Returns ERRVAL if something went wrong, OKVAL if everything is fine. */
int test(void);

/* Checks whether it's necessary to change the throttling state.
 * Returns OKVAL if no errors occured (regardless of whether the state was
 * canged or not) or ERRVAL on failure. */
int check(void);

/* Generates the array of throttling states using the high and low limits for
 * the CPU, the number of CPU throttling states and the number of ACPI
 * throttling states.
 * Returns OKVAL on success and ERRVAL on failure. */
int build_state_array(void);

/* Raises the throttling limit.
 * Returns OKVAL on success, ERRVAL on failure. */
int up(void);

/* Lowers the throttling limit.
 * Returns OKVAL on successs, ERRVAL on failure. */
int down(void);

/* Catches SIGHUP and calls the function that checks for AC power. */
void catch_int(int sig_num);

#endif
